==> teavm-classlib-0.5.1-sources.jar: org/teavm/classlib/java/lang/TAssertionError.java <==
/*
 *  Copyright 2014 Alexey Andreev.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.teavm.classlib.java.lang;

public class TAssertionError extends TError {
    private static final long serialVersionUID = -4113942229209340013L;

    public TAssertionError() {
        super();
    }

    public TAssertionError(TString message, TThrowable cause) {
        super(message, cause);
    }

    public TAssertionError(TObject message) {
        super(TString.valueOf(message));
    }

    public TAssertionError(boolean message) {
        super(TString.valueOf(message));
    }

    public TAssertionError(int message) {
        super(TString.valueOf(message));
    }

    public TAssertionError(char message) {
        super(TString.valueOf(message));
    }

    public TAssertionError(long message) {
        super(TString.valueOf(message));
    }

    public TAssertionError(float message) {
        super(TString.valueOf(message));
    }

    public TAssertionError(double message) {
        super(TString.valueOf(message));
    }
}

==> teavm-classlib-0.12.3-sources.jar: org/teavm/classlib/java/lang/TAssertionError.java <==
/*
 *  Copyright 2014 Alexey Andreev.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.teavm.classlib.java.lang;

public class TAssertionError extends TError {
    private static final long serialVersionUID = -4113942229209340013L;

    public TAssertionError() {
        super();
    }

    public TAssertionError(String message, TThrowable cause) {
        super(message, cause);
    }

    public TAssertionError(Object message) {
        super(TString.valueOf(message));
    }

    public TAssertionError(boolean message) {
        super(TString.valueOf(message));
    }

    public TAssertionError(int message) {
        super(TString.valueOf(message));
    }

    public TAssertionError(char message) {
        super(TString.valueOf(message));
    }

    public TAssertionError(long message) {
        super(TString.valueOf(message));
    }

    public TAssertionError(float message) {
        super(TString.valueOf(message));
    }

    public TAssertionError(double message) {
        super(TString.valueOf(message));
    }
}
